@@ -12,7 +12,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 
 use Rose::DB::Object::Constants qw(PRIVATE_PREFIX);
 
-our $VERSION = '0.711';
+our $VERSION = '0.725';
 
 our $Debug = 0;
 
@@ -232,32 +232,36 @@ sub is_ready_to_make_methods
       {
         # Skip if there was an explicit local relationship name and
         # this is not that name.
-        next  if($map_from && $item->name ne $map_from);
-
-        if(%map_column_to_self_method)
+        unless($map_from && $item->name ne $map_from)
         {
-          Carp::croak "Map class $map_class has more than one foreign key ",
-                      "and/or 'many to one' relationship that points to the ",
-                      "class $target_class.  Please specify one by name ",
-                      "with a 'local' parameter in the 'map' hash";
-        }
+          if(%map_column_to_self_method)
+          {
+            Carp::croak "Map class $map_class has more than one foreign key ",
+                        "and/or 'many to one' relationship that points to the ",
+                        "class $target_class.  Please specify one by name ",
+                        "with a 'local' parameter in the 'map' hash";
+          }
+  
+          $map_from = $local_rel = $item->name;
+  
+          my $map_columns = 
+            $item->can('column_map') ? $item->column_map : $item->key_columns;
+  
+          # "local" and "foreign" here are relative to the *mapper* class
+          while(my($local_column, $foreign_column) = each(%$map_columns))
+          {
+            my $foreign_method = $meta->column_accessor_method_name($foreign_column)
+              or Carp::croak "Missing accessor method for column '$foreign_column'", 
+                             " in class ", $meta->class;
+            $map_column_to_self_method{$local_column} = $foreign_method;
+            $map_column_to_self_column{$local_column} = $foreign_column;
+          }
 
-        $map_from = $local_rel = $item->name;
-
-        my $map_columns = 
-          $item->can('column_map') ? $item->column_map : $item->key_columns;
-
-        # "local" and "foreign" here are relative to the *mapper* class
-        while(my($local_column, $foreign_column) = each(%$map_columns))
-        {
-          my $foreign_method = $meta->column_accessor_method_name($foreign_column)
-            or Carp::croak "Missing accessor method for column '$foreign_column'", 
-                           " in class ", $meta->class;
-          $map_column_to_self_method{$local_column} = $foreign_method;
-          $map_column_to_self_column{$local_column} = $foreign_column;
+          next;
         }
       }
-      elsif($item->isa('Rose::DB::Object::Metadata::ForeignKey') ||
+
+      if($item->isa('Rose::DB::Object::Metadata::ForeignKey') ||
             $item->type eq 'many to one')
       {
         # Skip if there was an explicit foreign relationship name and
